@@ -6,11 +6,11 @@
 
 #include "settingspagebase.h"
 
-SettingsPageBase::SettingsPageBase(QWidget* parent) :
-        QWidget(parent)
-{}
+SettingsPageBase::SettingsPageBase(QWidget *parent)
+    : QWidget(parent)
+{
+}
 
 SettingsPageBase::~SettingsPageBase()
-{}
-
-
+{
+}
